pub struct Mint {
pub mint_authority: Option<Pubkey>,
pub supply: u64,
pub decimals: u8,
pub is_initialized: bool,
pub freeze_authority: Option<Pubkey>,
}Fields
Optional authority used to mint new tokens. The mint authority may only be provided during mint creation. If no mint authority is present then the mint has a fixed supply and no further tokens may be minted.
supply: u64Total supply of tokens.
decimals: u8Number of base 10 digits to the right of the decimal place.
is_initialized: boolIs true if this structure has been initialized.
Optional authority to freeze token accounts.
Implementations