pub struct Approve {
pub amount: u64,
}Expand description
Approves a delegate. A delegate is given the authority over tokens on behalf of the source account’s owner.
Fields
amount: u64The amount of tokens the delegate is approved for.
Implementations