Module approve_checked

Module approve_checked 

This code was AUTOGENERATED using the Codama library.

Structs

ApproveChecked
Approves a delegate. A delegate is given the authority over tokens on behalf of the source account’s owner. This instruction differs from Approve in that the token mint and decimals value is checked by the caller. This may be useful when creating transactions offline or within a hardware wallet.
ApproveCheckedInstructionAccounts