pub struct ApproveChecked {
pub amount: u64,
pub decimals: u8,
}Expand description
Approves a delegate. A delegate is given the authority over tokens on behalf of the source account’s owner. This instruction differs from Approve in that the token mint and decimals value is checked by the caller. This may be useful when creating transactions offline or within a hardware wallet.
Fields
amount: u64The amount of tokens the delegate is approved for.
decimals: u8Expected number of base 10 digits to the right of the decimal place.
Implementations