Module burn_checked

Module burn_checked 

This code was AUTOGENERATED using the Codama library.

Structs

BurnChecked
Burns tokens by removing them from an account. BurnChecked does not support accounts associated with the native mint, use CloseAccount instead. This instruction differs from Burn in that the decimals value is checked by the caller. This may be useful when creating transactions offline or within a hardware wallet.
BurnCheckedInstructionAccounts