BurnChecked

Struct BurnChecked 

pub struct BurnChecked {
    pub amount: u64,
    pub decimals: u8,
}
Burns tokens by removing them from an account. BurnChecked does not support accounts associated with the native mint, use CloseAccount instead. This instruction differs from Burn in that the decimals value is checked by the caller. This may be useful when creating transactions offline or within a hardware wallet.

Fields

amount: u64

The amount of tokens to burn.

decimals: u8

Expected number of base 10 digits to the right of the decimal place.

Implementations

Source

impl BurnChecked

pub fn decode(data: &[u8]) -> Option<Self>