Module get_account_data_size

Module get_account_data_size 

This code was AUTOGENERATED using the Codama library.

Structs

GetAccountDataSize
Gets the required size of an account for the given mint as a little-endian u64. Return data can be fetched using sol_get_return_data and deserializing the return data as a little-endian u64.
GetAccountDataSizeInstructionAccounts