Module initialize_account2

Module initialize_account2 

This code was AUTOGENERATED using the Codama library.

Structs

InitializeAccount2
Like InitializeAccount, but the owner pubkey is passed via instruction data rather than the accounts list. This variant may be preferable when using Cross Program Invocation from an instruction that does not need the owner’s AccountInfo otherwise.
InitializeAccount2InstructionAccounts