Module initialize_immutable_owner

Module initialize_immutable_owner 

This code was AUTOGENERATED using the Codama library.

Structs

InitializeImmutableOwner
Initialize the Immutable Owner extension for the given token account Fails if the account has already been initialized, so must be called before InitializeAccount. No-ops in this version of the program, but is included for compatibility with the Associated Token Account program.
InitializeImmutableOwnerInstructionAccounts