Module initialize_mint

Module initialize_mint 

This code was AUTOGENERATED using the Codama library.

Structs

InitializeMint
Initializes a new mint and optionally deposits all the newly minted tokens in an account. The InitializeMint instruction requires no signers and MUST be included within the same Transaction as the system program’s CreateAccount instruction that creates the account being initialized. Otherwise another party can acquire ownership of the uninitialized account.
InitializeMintInstructionAccounts