pub struct InitializeMint {
pub decimals: u8,
pub mint_authority: Pubkey,
pub freeze_authority: Option<Pubkey>,
}Expand description
Initializes a new mint and optionally deposits all the newly minted
tokens in an account.
The InitializeMint instruction requires no signers and MUST be
included within the same Transaction as the system program’s
CreateAccount instruction that creates the account being initialized.
Otherwise another party can acquire ownership of the uninitialized account.
Fields
decimals: u8Number of decimals in token account amounts.
Minting authority.
Optional authority that can freeze token accounts.
Implementations