This code was AUTOGENERATED using the Codama library.
Structs
- Initialize
Mint2 - Like [
InitializeMint], but does not require the Rent sysvar to be provided. - Initialize
Mint2 Instruction Accounts
This code was AUTOGENERATED using the Codama library.
InitializeMint], but does not require the Rent sysvar to be
provided.