Module mint_to_checked

Module mint_to_checked 

This code was AUTOGENERATED using the Codama library.

Structs

MintToChecked
Mints new tokens to an account. The native mint does not support minting. This instruction differs from MintTo in that the decimals value is checked by the caller. This may be useful when creating transactions offline or within a hardware wallet.
MintToCheckedInstructionAccounts