Module sync_native

Module sync_native 

This code was AUTOGENERATED using the Codama library.

Structs

SyncNative
Given a wrapped / native token account (a token account containing SOL) updates its amount field based on the account’s underlying lamports. This is useful if a non-wrapped SOL account uses system_instruction::transfer to move lamports to a wrapped token account, and needs to have its token amount field updated.
SyncNativeInstructionAccounts