Module transfer

Module transfer 

This code was AUTOGENERATED using the Codama library.

Structs

Transfer
Transfers tokens from one account to another either directly or via a delegate. If this account is associated with the native mint then equal amounts of SOL and Tokens will be transferred to the destination account.
TransferInstructionAccounts