This code was AUTOGENERATED using the Codama library.
Structs
- Transfer
Checked - Transfers tokens from one account to another either directly or via a delegate. If this account is associated with the native mint then equal amounts of SOL and Tokens will be transferred to the destination account. This instruction differs from Transfer in that the token mint and decimals value is checked by the caller. This may be useful when creating transactions offline or within a hardware wallet.
- Transfer
Checked Instruction Accounts