Module ui_amount_to_amount

Module ui_amount_to_amount 

This code was AUTOGENERATED using the Codama library.

Structs

UiAmountToAmount
Convert a UiAmount of tokens to a little-endian u64 raw Amount, using the given mint. In this version of the program, the mint can only specify the number of decimals. Return data can be fetched using sol_get_return_data and deserializing the return data as a little-endian u64.
UiAmountToAmountInstructionAccounts