This code was AUTOGENERATED using the Codama library.
Structs
- Burn
Checked - Burns tokens by removing them from an account.
BurnCheckeddoes not support accounts associated with the native mint, useCloseAccountinstead. This instruction differs from Burn in that the decimals value is checked by the caller. This may be useful when creating transactions offline or within a hardware wallet. - Burn
Checked Instruction Accounts