pub struct BurnChecked {
pub amount: u64,
pub decimals: u8,
}Expand description
Burns tokens by removing them from an account. BurnChecked does not
support accounts associated with the native mint, use CloseAccount
instead. This instruction differs from Burn in that the decimals value is
checked by the caller. This may be useful when creating transactions offline
or within a hardware wallet.
Fields
amount: u64The amount of tokens to burn.
decimals: u8Expected number of base 10 digits to the right of the decimal place.
Implementations