This code was AUTOGENERATED using the Codama library.
Structs
- Initialize
Account - Initializes a new account to hold tokens. If this account is associated
with the native mint then the token balance of the initialized account
will be equal to the amount of SOL in the account. If this account is
associated with another mint, that mint must be initialized before this
command can succeed.
The
InitializeAccountinstruction requires no signers and MUST be included within the same Transaction as the system program’sCreateAccountinstruction that creates the account being initialized. Otherwise another party can acquire ownership of the uninitialized account. - Initialize
Account Instruction Accounts