This code was AUTOGENERATED using the Codama library.
Structs
- Initialize
Mint - Initializes a new mint and optionally deposits all the newly minted
tokens in an account.
The
InitializeMintinstruction requires no signers and MUST be included within the same Transaction as the system program’sCreateAccountinstruction that creates the account being initialized. Otherwise another party can acquire ownership of the uninitialized account. - Initialize
Mint Instruction Accounts